@@ -1,4 +1,4 @@
-#' Network Meta-Analysis Using the Hierarchical Model
+#' Hierarchical Model for Network Meta-Analysis of Diagnostic Accuracy Studies
 #' @description \code{nmadt.hierarchical} performs meta-analysis using the hierarchical model \insertCite{Ma2018}{NMADTA} and outputs CIs for accuracy measurements.
 #' @param nstu an integer indicating the number of studies included in the dataset.
 #' @param K an integer indicating the number of candiate test in the dataset.
@@ -25,13 +25,23 @@
 #' @param dic a logical value indicating whether the function will output the deviance information criterion (DIC) statistic. The default is \code{false}.
 #' @param mcmc.samples a logical value indicating whether the coda samples generated in the meta-analysis. The default is \code{FALSE}.
 #' @return A list with the raw output for graphing the results, the effect size estimates, which lists the posterior mean, standard deviation, median, and a $95$\% equal tail credible interval for the median.
+#' 
+#' @note
+#' This example uses a small number of MCMC iterations (n.iter = 500) for demonstration.
+#' For real-world analyses, longer chains (e.g., n.iter = 50000) are recommended
+#' to achieve convergence and stable posterior summaries.
+#' 
 #' @examples
-#' \donttest{
-#' kangdata<-read.csv(file=system.file("extdata","kangdata.csv",package="NMADTA"),
-#' header=TRUE, sep=",")
+#' 
+#' data(dat.kang)
 #' set.seed(9)
-#' kang.out <- nmadt.hierarchical(nstu=12, K=2, data=kangdata, testname=c("D-dimer","Ultrasonography"))
-#' }
+#' kang.out <- nmadt.hierarchical(nstu = 12, K = 2, data = dat.kang,
+#'                                directory = tempdir(), testname = c("D-dimer", "Ultrasonography"),
+#'                                diag = 5, off_diag = 0.05, digits = 4, mu_alpha = 0, mu_beta = 0,
+#'                                mu_eta = 0, preci_alpha = 0.1, preci_beta = 0.1, preci_eta = 0.1,
+#'                                n.adapt = 1000, n.iter = 500, n.chains = 3, conv.diag = TRUE,
+#'                                trace = "prev", dic = TRUE, mcmc.samples = FALSE)
+#' 
 #' @import rjags
 #' @import coda
 #' @import MASS
@@ -40,6 +50,9 @@
 #' @importFrom Rdpack reprompt
 #' @references
 #' \insertRef{Ma2018}{NMADTA}
+#' 
+#' @keywords Test
+#' 
 #' @export
 nmadt.hierarchical=function(nstu, K, data, testname, directory=NULL,
                             diag = 5, off_diag = 0.05, digits = 4, mu_alpha=0,
@@ -100,16 +113,23 @@ nmadt.hierarchical=function(nstu, K, data, testname, directory=NULL,
   monitor<-c('pi','post.Se','post.Sp','Se.stud','Sp.stud','mu','prev','ppv','npv','LRpos','LRneg','Cov')
   data.jags <- list('n' = n, 'delta'=delta,'N' = N,'y'=y,'K'=K,'R'=R,'df'=df,'nstu'=nstu,'sid'=sid,'mu_alpha'=mu_alpha,'mu_beta'=mu_beta,'mu_eta'=mu_eta,
                     'preci_alpha'=preci_alpha,'preci_beta'=preci_beta,'preci_eta'=preci_eta)
-  #rng.seeds <- sample(1e+06, n.chains)
-  init<-list()
+  seed <- sample(1000000, 1)
+  set.seed(seed)
+  init.seeds <- sample(1:100000, n.chains) 
+  
+  init<-vector("list", n.chains)
+  
   mu.inits<-c(mu_eta,rep(c(mu_alpha,mu_beta),K))
   for(i in 1:n.chains){
     init[[i]]<-list(mu=mu.inits,.RNG.name = "base::Wichmann-Hill",
-                    .RNG.seed = i)
+                    .RNG.seed = init.seeds[i])
   }
   message("Start running MCMC...\n")
   model<-system.file("JAGSmodels", "model_h1.txt", package="NMADTA")
-  jags.m <-jags.model(model, data = data.jags, n.chains = n.chains, n.adapt = n.adapt)
+  
+  set.seed(seed)
+  jags.m <-jags.model(model, data = data.jags, inits = init,
+                      n.chains = n.chains, n.adapt = n.adapt)
   update(jags.m, n.iter = n.burnin)
   jags.out <- coda.samples(model = jags.m, variable.names = monitor,
                            n.iter = n.iter, thin = n.thin)
@@ -366,6 +386,10 @@ nmadt.hierarchical=function(nstu, K, data, testname, directory=NULL,
       dev.off()
     }
   }
+  out$dat <- data
+  out$K <- K
+  out$nstu <- nstu
+  out$testname <- testname
   class(out) <- "nmadt"
   return(out)
   #options(warn = 0)
